summary refs log tree commit diff
path: root/src/libnm-core-public/nm-vpn-editor-plugin.h
diff options
context:
space:
mode:
authorMichael Biebl <biebl@debian.org>2025-02-12 13:46:50 +0100
committerMichael Biebl <biebl@debian.org>2025-02-12 13:46:50 +0100
commit8bdf070ff046f482f6eb5e2b15ebc216f5d1e3da (patch)
treef706478d189d54c6532e8863d4b0d5ff5575af60 /src/libnm-core-public/nm-vpn-editor-plugin.h
parent818258cf34b83fbc754633295e1052d4752d7b15 (diff)
New upstream version 1.51.90 upstream/1.51.90
Diffstat (limited to 'src/libnm-core-public/nm-vpn-editor-plugin.h')
-rw-r--r--src/libnm-core-public/nm-vpn-editor-plugin.h24
1 files changed, 13 insertions, 11 deletions
diff --git a/src/libnm-core-public/nm-vpn-editor-plugin.h b/src/libnm-core-public/nm-vpn-editor-plugin.h
index 4e632244..0f9801ef 100644
--- a/src/libnm-core-public/nm-vpn-editor-plugin.h
+++ b/src/libnm-core-public/nm-vpn-editor-plugin.h
@@ -32,9 +32,9 @@ typedef NMVpnEditorPlugin *(*NMVpnEditorPluginFactory)(GError **error);
 NMVpnEditorPlugin *nm_vpn_editor_plugin_factory(GError **error);
 #endif
 
-/*****************************************************************************/
-/* Editor plugin interface                        */
-/*****************************************************************************/
+/*
+ * Editor plugin interface
+ */
 
 #define NM_TYPE_VPN_EDITOR_PLUGIN (nm_vpn_editor_plugin_get_type())
 #define NM_VPN_EDITOR_PLUGIN(obj) \
@@ -45,18 +45,20 @@ NMVpnEditorPlugin *nm_vpn_editor_plugin_factory(GError **error);
 
 /**
  * NMVpnEditorPluginCapability:
  * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_NONE: unknown or no capability
  * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_IMPORT: the plugin can import new connections
  * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_EXPORT: the plugin can export connections
  * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_IPV6: the plugin supports IPv6 addressing
  *
  * Flags that indicate certain capabilities of the plugin to editor programs.
  **/
 typedef enum /*< flags >*/ {
-    NM_VPN_EDITOR_PLUGIN_CAPABILITY_NONE   = 0x00,
-    NM_VPN_EDITOR_PLUGIN_CAPABILITY_IMPORT = 0x01,
-    NM_VPN_EDITOR_PLUGIN_CAPABILITY_EXPORT = 0x02,
-    NM_VPN_EDITOR_PLUGIN_CAPABILITY_IPV6   = 0x04
+    NM_VPN_EDITOR_PLUGIN_CAPABILITY_NONE      = 0x00,
+    NM_VPN_EDITOR_PLUGIN_CAPABILITY_IMPORT    = 0x01,
+    NM_VPN_EDITOR_PLUGIN_CAPABILITY_EXPORT    = 0x02,
+    NM_VPN_EDITOR_PLUGIN_CAPABILITY_IPV6      = 0x04,
+    NM_VPN_EDITOR_PLUGIN_CAPABILITY_NO_EDITOR = 0x08,
 } NMVpnEditorPluginCapability;
 
 /* Short display name of the VPN plugin */
@@ -45,18 +45,20 @@ NMVpnEditorPlugin *nm_vpn_editor_plugin_factory(GError **error);
 /**
  * NMVpnEditorPluginCapability:
- * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_NONE: unknown or no capability
- * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_IMPORT: the plugin can import new connections
- * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_EXPORT: the plugin can export connections
- * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_IPV6: the plugin supports IPv6 addressing
+ * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_NONE: Unknown or no capability.
+ * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_IMPORT: The plugin can import new connections.
+ * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_EXPORT: The plugin can export connections.
+ * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_IPV6: The plugin supports IPv6 addressing.
+ * @NM_VPN_EDITOR_PLUGIN_CAPABILITY_NO_EDITOR: The GUI editor plugin is not available. Since: 1.52.
  *
  * Flags that indicate certain capabilities of the plugin to editor programs.